embassy-stm32

Crates

git

Versions

stm32g441vb

Flavors

InjectedAdc

Struct InjectedAdc 

pub struct InjectedAdc<'d, R: InjectedAdcRegs> { /* private fields */ }
Injected ADC sequence with owned channels.

Implementations

Source

impl<'d, R: InjectedAdcRegs> InjectedAdc<'d, R>

pub fn stop_injected_conversions(&mut self)

Stops injected convention.

Any ongoing injected conversion is aborted with partial result discarded.

pub fn start_injected_conversions(&mut self)

Starts injected convention:

  • Immediately if in software trigger mode (JEXTEN = 0)
  • At the next active edge of the selected injected hardware trigger (JEXTEN != 0)
pub async fn read(&mut self, buf: &mut [u16])

Reads injected convention result after the end of sequence is detected.

pub fn read_latest(&mut self, buf: &mut [u16])

Reads latest result directly from the injected convention registers.

This function is intended to be used in a custom interrupt handler. For other use cases prefer read function.