pub struct InjectedAdc<'d, R: InjectedAdcRegs> { /* private fields */ }Expand description
Injected ADC sequence with owned channels.
Implementations
Sourceimpl<'d, R: InjectedAdcRegs> InjectedAdc<'d, R>
impl<'d, R: InjectedAdcRegs> InjectedAdc<'d, R>
Sourcepub fn stop_injected_conversions(&mut self)
pub fn stop_injected_conversions(&mut self)
Stops injected convention.
Any ongoing injected conversion is aborted with partial result discarded.
Sourcepub fn start_injected_conversions(&mut self)
pub fn start_injected_conversions(&mut self)
Starts injected convention:
- Immediately if in software trigger mode (JEXTEN = 0)
- At the next active edge of the selected injected hardware trigger (JEXTEN != 0)
Sourcepub async fn read(&mut self, buf: &mut [u16])
pub async fn read(&mut self, buf: &mut [u16])
Reads injected convention result after the end of sequence is detected.
Sourcepub fn read_latest(&mut self, buf: &mut [u16])
pub fn read_latest(&mut self, buf: &mut [u16])
Reads latest result directly from the injected convention registers.
This function is intended to be used in a custom interrupt handler.
For other use cases prefer read function.